Module config

Module config 

Configuration management for Pinner.

This module handles loading configuration from files (e.g., .pinner.toml) and environment variables, merging them with CLI arguments.

Structs

Config
Configuration for Pinner, typically loaded from a file or environment.
SecurityEntry
Represents an entry in the vetted or compromised lists, which can include a version and timestamp.